@@ -21,7 +21,7 @@
 #ifndef _INTERNAL_H
 #define _INTERNAL_H
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
@@ -34,9 +34,8 @@
 #include <stdbool.h>
 
 #include <sys/types.h>
-#include <sys/socket.h>	/* for AF_INET */
-#include <sys/select.h> /* select() */
-#include <sys/time.h>	/* select() */
+#include <sys/socket.h>		/* for AF_INET */
+#include <poll.h>		/* poll() */
 #include <unistd.h>
 #include <netinet/in.h>
 #ifdef HAVE_NETDB_H
